ReplaceError

Enum ReplaceError 

pub enum ReplaceError {
    OpenTooDeep,
    InconsistentOpenDepths,
    CannotJoin {
        onto: String,
        joined: String,
    },
    InvalidContent {
        parent: String,
    },
    Position {
        pos: usize,
        max: usize,
    },
}
Why a Node::replace could not be performed.

Variants



OpenTooDeep

The slice’s open depth exceeds the insertion position’s depth.



InconsistentOpenDepths

from’s and to’s open depths are inconsistent with the slice.



CannotJoin

Two nodes that would have to be joined have incompatible content.

Fields

onto: String

The node type being joined on.

joined: String

The node type being joined.



InvalidContent

The resulting content would violate the schema for parent.

Fields

parent: String

The parent node type whose content became invalid.



Position

A boundary position was out of range.

Fields

pos: usize

The offending position.

max: usize

The maximum valid position.