pub enum ReplaceError {
OpenTooDeep,
InconsistentOpenDepths,
CannotJoin {
onto: String,
joined: String,
},
InvalidContent {
parent: String,
},
Position {
pos: usize,
max: usize,
},
}Expand description
Why a Node::replace could not be performed.
Variants
OpenTooDeep
The slice’s open depth exceeds the insertion position’s depth.
InconsistentOpenDepths
from’s and to’s open depths are inconsistent with the slice.
CannotJoin
Two nodes that would have to be joined have incompatible content.
InvalidContent
The resulting content would violate the schema for parent.
Position
A boundary position was out of range.